@@ -1,4 +1,4 @@
-`dri.fix.missingvals` <-
+dri.fix.missingvals <-
 function(d) {
 	d[d == -999999] <- NA
 	return (d)
