@@ -1,4 +1,4 @@
-`sum.fp` <-
+sum.fp <-
 function(null.column, cutoff) {
 	return(sum(null.column>cutoff))
 }
